(****************************************************************************
 *                      PalmScan v1.13 FileInfo system                      *
 *                                                                          *
 *        Copyright (C) 1993,94 Steven Hendriks, all rights reserved        *
 *                                                                          *
 *  Information in this document is subject to change without prior notice  *
 ****************************************************************************)

Type
     FileInfoBlock = Record
                      CreatedBy   : String[60]; {Created by which program}
                      Area        : String[60];
                      FileName    : String[12];
                      NewName     : String[12]; {The new filename after
                                                 archive conversion}
                      FilePath    : String[60];
                      TickFile    : String[12]; {The filename of the
                                                 accompanying tick-file,
                                                 if any}
                      ConvertTo   : String[3];  {Archive format to convert to}

                      Attrib1     : Byte;
                      { Bitmapped : 0 - Bit 1 used
                                    1 - Virus Scan
                                    2 - Bit 3 used
                                    3 - Convert All
                                    4 - Bit 5 used
                                    5 - Add GIF specs
                                    6 - Bit 7 used
                                    7 - Import FILE_ID.DIZ description }

                      Attrib2     : Byte;
                      { Bitmapped : 0 - Bit 1 used
                                    1 - Convert AV
                                    2 - Bit 3 used
                                    3 - Convert embedded archives
                                    4 - Bit 5 used
                                    5 - Reserved
                                    6 - Bit 7 used
                                    7 - Reserved                  }

                      Result      : Byte;
                      { Bitmapped : 0 - Infected
                                    1 - Bad archive (can't be unpacked)
                                    2-7 - Unused                        }

                      ExtraSpace  : Array[1..367] of Byte;
                      DescriptionSize : LongInt;
                     End;

{ The FileInfo file should be named FILEINFO.FIX, and placed in the
  current directory (the directory from where PalmScan is executed).

  It consists of FileInfoBlocks and DescriptionBlocks. The
  DescriptionBlock is placed right after each FileInfoBlock, and should be
  normal ascii text.

  FILEINFO.FIX : .==================.
                 | FileInfoBlock    | \
                 +------------------+  > File #1
                 | DescriptionBlock | /
                 +==================+
                 | FileInfoBlock    | \
                 +------------------+  > File #2
                 | DescriptionBlock | /
                 +==================+
                 | etc...           |


  FileInfoBlock descriptions:


  CreatedBy     : Which program created this FileInfo file.

  Area          : The area name in which this file arrived/exists.

  FileName      : The filename of this file.

  NewName       : When PalmScan has processed this file, this will be the
                  filename after conversion. When empty, PalmScan has not
                  processed this file.

  FilePath      : The directory where this file resides.

  TickFile      : The filename of the tick-file accompanying this file. This
                  is not used by PalmScan, though it can be of use for some
                  file echo processors.

  ConvertTo     : The archive format to which this archive should be
                  converted. When empty, no archive conversion will be done.
                  ANY = Use default archiver.
                  Examples : ARC,ZIP,LHA,ZOO,SQZ,HYP,ARJ,HAP,PAK,UC2,RAR

  Attrib1       : bits 0,1 - Should files be scanned for virusses
                             0,x = Use default settings
                             1,0 = No
                             1,1 = Yes

                  bits 2,3 - Should files which are already in the target
                             format (ConverTo) also be converted
                             0,x = Use default settings
                             1,0 = No
                             1,1 = Yes

                  bits 4,5 - Should GIF specifications be added to
                             descriptions
                             0,x = Use default settings
                             1,0 = No
                             1,1 = Yes

                  bits 6,7 - Should FILE_ID.DIZ/DESC.SDI descriptions be
                             imported
                             0,x = Use default settings
                             1,0 = No
                             1,1 = Yes

  Attrib2       : bits 0,1 - Should archives which have a valid security
                             envelope or authenticity validation be converted
                             0,x = Use default settings
                             1,0 = No
                             1,1 = Yes

                  bits 2,3 - Should embedded archives be converted
                             0,x = Use default settings
                             1,0 = No
                             1,1 = Yes

                  bits 4-7 are reserved for future use

  Result        : bit 0 - If set, infected files were found inside this
                          archive
                  bit 1 - If set, the archive is corrupt (ie. couldn't be
                          unpacked by the archiver for this archive type).
                  bits 2-7 are not used yet

  DescriptionSize : The size in bytes of the DescriptionBlock, which is
                    placed after each FileInfoBlock.

}

(* End of FILEINFO.INC *)
